@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, Optional, Union
 
 from easydata.parsers.text import Text
 from easydata.utils import price
@@ -15,10 +15,14 @@ class PriceFloat(Text):
         self,
         *args,
         decimals: Optional[int] = None,
+        min_value: Optional[Union[float, int]] = None,
+        max_value: Optional[Union[float, int]] = None,
         **kwargs,
     ):
 
         self.__decimals = decimals
+        self.__min_value = min_value
+        self.__max_value = max_value
 
         super().__init__(
             *args,
@@ -32,6 +36,14 @@ class PriceFloat(Text):
 
         return self.__decimals or self.config["ED_PRICE_DECIMALS"]
 
+    @property
+    def _min_value(self):
+        return self.__min_value or self.config["ED_PRICE_MIN_VALUE"]
+
+    @property
+    def _max_value(self):
+        return self.__max_value or self.config["ED_PRICE_MAX_VALUE"]
+
     def _parse_value(
         self,
         value: Any,
@@ -44,13 +56,30 @@ class PriceFloat(Text):
         )
 
         if value:
-            return price.to_float(
+            value = price.to_float(
                 price_value=value,
                 decimals=self._decimals,
             )
 
+            if value is None:
+                return None
+
+            return self._process_min_max_value(value)
+
         return None
 
+    def _process_min_max_value(self, value: float) -> Optional[float]:
+        min_value = self._min_value
+        max_value = self._max_value
+
+        if min_value and value < min_value:
+            return None
+
+        if max_value and value > max_value:
+            return None
+
+        return value
+
 
 class PriceInt(PriceFloat):
     def _parse_value(
